# conn-check interface 

Use this interface to register conn-check checks in your charm layers.

## Prupose

This interface is designed to interoperate with the 
[conn-check](https://jujucharms.com/u/ubuntuone-hackers/conn-check/) subordinate charm.

## How to use in your layers 

The event handler for `conn-check.available` is called with an object through which 
you can register your own custom conn-check checks, when a relation is established with
 `conn-check:conn-check`.

This object provides 3 methods: 

1) _add_check_(name, check_dict)

Which is called to add/register conn-check checks for your service.

All arguments are required.

*name* a unique name for this check 

*check_dict* a dict with the conn-check check config

2) _update_(nagios_context=_nagios_context_)

Called at the end of the handler to apply the changes to the subordinate via a set_remote

*nagios_context* the nagios_context for the checks (usually part of your charm config)


Example: 

```
@when('conn-check.available')
def setup_conn_check(conn_check):
    config = hookenv.config()
    conn_check.add_check('some_resource', {'type': 'tcp', 'host': 'some-host', 'port': 8080})
    conn_check.update(nagios_context=config['nagios_context'])
```

Consult conn-check documentation for more information on the [check types and options](http://conn-check.readthedocs.org/en/latest/readme.html#check-types)

