import yaml


from charmhelpers.core import hookenv

from charms import reactive
from charms.reactive import hook, RelationBase, scopes


class ConnCheckRelation(RelationBase):
    scope = scopes.UNIT

    def __init__(self, *args, **kw):
        super(ConnCheckRelation, self).__init__(*args, **kw)
        self._checks = {}

    @hook('{provides:conn-check}-relation-{changed,joined}')
    def changed_joined(self):
        self.set_state('conn-check.available')

    @hook('{provides:conn-check}-relation-{departed,broken}')
    def departed_broken(self):
        reactive.remove_state('conn-check.available')

    def add_check(self, name, check):
        self._checks[name] = check

    def update(self, nagios_context=None):
        if not hookenv.hook_name().startswith('conn-check') or \
                hookenv.hook_name().endswith('broken'):
            return
        if self._checks:
            cc_config = yaml.dump(list(self._checks.values()))
            remote = {'config': cc_config}
            if nagios_context is not None:
                remote['nagios_context'] = nagios_context
            self.set_remote(**remote)
